@@ -216,7 +216,7 @@ class SimpleDiskCache(AbstractCache):
         """ Return the path to the SQLite3 file. """
         return str(self.directory / self.name)
 
-    def set(self, key: str, value: Any, timeout: Number = DEFAULT_TIMEOUT,
+    def set(self, key: str, value: Any, timeout: Time = DEFAULT_TIMEOUT,
             tag: TG = DEFAULT_TAG) -> bool:
 
         store_key: str = self.store_key(key, tag)
@@ -347,7 +347,7 @@ class SimpleDiskCache(AbstractCache):
             value: Any = self.deserialize(serial_value)
             yield key, value
 
-    def touch(self, key: str, timeout: Number, tag: TG = DEFAULT_TAG) -> bool:
+    def touch(self, key: str, timeout: Time, tag: TG = DEFAULT_TAG) -> bool:
         """ Renew the key. When the key does not exist, false will be returned """
 
         store_key: str = self.store_key(key, tag)
@@ -515,7 +515,7 @@ class SimpleDiskCache(AbstractCache):
     def restore_key(self, serial_key: str) -> str:
         return serial_key
 
-    def evict(self) -> NoReturn:
+    def lru(self) -> NoReturn:
         """ It is called by the master logic, and there is no need to
         care about when to schedule. """
 
