@@ -10,7 +10,7 @@ from typing import Tuple
 #    INFORMATION
 ####################
 PROJECT: str = 'cache3'
-VERSION: Tuple[int, int, int] = (0, 2, 2)
+VERSION: Tuple[int, int, int] = (0, 3, 1)
 
 ####################
 #    DEFAULT SETTING
@@ -31,9 +31,4 @@ MIN_KEY_LENGTH: int = 1
 MAX_TIMEOUT: int = 365 * 24 * 60 * 60
 MIN_TIMEOUT: int = 0
 
-
-LRU: str = 'lru'
-FIFO: str = 'fifo'
-LFU: str = 'lfu'
-
-DEFAULT_EVICT: str = LRU
+LRU_EVICT: str = 'lru'
